﻿/*
Copyright (c) 2003-2021, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'colorbutton', 'ar', {
	auto: 'تلقائي',
	bgColorTitle: 'لون الخلفية',
	colors: {
		'000': 'أسود',
		'800000': 'كستنائي',
		'8B4513': 'بني فاتح',
		'2F4F4F': 'رمادي أردوازي غامق',
		'008080': 'أزرق مخضر',
		'000080': 'أزرق داكن',
		'4B0082': 'كحلي',
		'696969': 'رمادي داكن',
		B22222: 'طوبي',
		A52A2A: 'بني',
		DAA520: 'ذهبي داكن',
		'006400': 'أخضر داكن',
		'40E0D0': 'فيروزي',
		'0000CD': 'أزرق متوسط',
		'800080': 'بنفسجي غامق',
		'808080': 'رمادي',
		F00: 'أحمر',
		FF8C00: 'برتقالي داكن',
		FFD700: 'ذهبي',
		'008000': 'أخضر',
		'0FF': 'تركواز',
		'00F': 'أزرق',
		EE82EE: 'بنفسجي',
		A9A9A9: 'رمادي شاحب',
		FFA07A: 'برتقالي وردي',
		FFA500: 'برتقالي',
		FFFF00: 'أصفر',
		'00FF00': 'ليموني',
		AFEEEE: 'فيروزي شاحب',
		ADD8E6: 'أزرق فاتح',
		DDA0DD: 'بنفسجي فاتح',
		D3D3D3: 'رمادي فاتح',
		FFF0F5: 'وردي فاتح',
		FAEBD7: 'أبيض عتيق',
		FFFFE0: 'أصفر فاتح',
		F0FFF0: 'أبيض مائل للأخضر',
		F0FFFF: 'سماوي',
		F0F8FF: 'لبني',
		E6E6FA: 'أرجواني',
		FFF: 'أبيض',
		'1ABC9C': 'Strong Cyan', // MISSING
		'2ECC71': 'Emerald', // MISSING
		'3498DB': 'Bright Blue', // MISSING
		'9B59B6': 'Amethyst', // MISSING
		'4E5F70': 'Grayish Blue', // MISSING
		'F1C40F': 'Vivid Yellow', // MISSING
		'16A085': 'Dark Cyan', // MISSING
		'27AE60': 'Dark Emerald', // MISSING
		'2980B9': 'Strong Blue', // MISSING
		'8E44AD': 'بنفسجي غامق',
		'2C3E50': 'Desaturated Blue', // MISSING
		'F39C12': 'برتقالي',
		'E67E22': 'Carrot', // MISSING
		'E74C3C': 'Pale Red', // MISSING
		'ECF0F1': 'Bright Silver', // MISSING
		'95A5A6': 'Light Grayish Cyan', // MISSING
		'DDD': 'رمادي فاتح',
		'D35400': 'Pumpkin', // MISSING
		'C0392B': 'Strong Red', // MISSING
		'BDC3C7': 'فضي',
		'7F8C8D': 'Grayish Cyan', // MISSING
		'999': 'رمادي غامق'
	},
	more: 'ألوان إضافية...',
	panelTitle: 'Colors',
	textColorTitle: 'لون النص'
} );
